pub struct PagePointsBreakdown {
pub page_id: Uuid,
pub title: String,
pub url_path: String,
pub score_given: f32,
pub score_maximum: i32,
pub exercises: Vec<ExercisePointsBreakdown>,
}Expand description
A page’s exercises in a points breakdown, with their subtotal.
Fields
page_id: Uuidtitle: Stringurl_path: StringPath within the course; the exercise’s block is anchored on the page by its exercise id.
score_given: f32score_maximum: i32exercises: Vec<ExercisePointsBreakdown>Trait Implementations
Sourceimpl Clone for PagePointsBreakdown
impl Clone for PagePointsBreakdown
Sourcefn clone(&self) -> PagePointsBreakdown
fn clone(&self) -> PagePointsBreakdown
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl ComposeSchema for PagePointsBreakdown
impl ComposeSchema for PagePointsBreakdown
Sourceimpl Debug for PagePointsBreakdown
impl Debug for PagePointsBreakdown
Sourceimpl<'de> Deserialize<'de> for PagePointsBreakdown
impl<'de> Deserialize<'de> for PagePointsBreakdown
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for PagePointsBreakdown
impl PartialEq for PagePointsBreakdown
Sourceimpl Serialize for PagePointsBreakdown
impl Serialize for PagePointsBreakdown
Sourceimpl ToSchema for PagePointsBreakdown
impl ToSchema for PagePointsBreakdown
impl StructuralPartialEq for PagePointsBreakdown